/*
** this is reserved for official patches released by me (the author - 
** Ashley Roll). If you have a patch then please release it via me - you 
** will be credited with creating it. You can E-Mail me at:
** A.Roll@cit.gu.edu.au or ash@splat.paxnet.com.au
*/
#define PATCHLEVEL "0"
#define VERSION "3"

/*********************************************************
** These patches applied before version 2.0 was written **
**********************************************************/
/* patch01 applyed. 
 * This patch was recieved from Lee McLoughlin (lmjm@twerp.doc.ic.ac.uk) 
 * on the 6th January 1993
 *
 * Here is a minor patch to xminesweeper.  The types of
 * some of the uses of XEvent were missing a '*' and the subsequent uses
 * were event. and not event->.  This doesn't matter on some machines
 * but it caused the game to be *real* weird on my 386BSD box.
 */

/**************************************
** These are the version 2.0 patches **
***************************************/
/*
 * patch: 01
 * bug identified in get_pos() by George Phillips <phillips@cs.ubc.ca>
 * patch created by George Phillips <phillips@cs.ubc.ca>.
 */

/**************************************
** These are the version 3.0 patches **
***************************************/

